@@ -9,7 +9,7 @@ from datetime import datetime, timedelta
 from urllib.parse import unquote, urlparse
 from banal import hash_data, is_mapping
 from urlnormalizer import normalize_url
-from celestial import parse_mimetype, normalize_mimetype
+from pantomime import parse_mimetype, normalize_mimetype
 from normality import guess_file_encoding, stringify
 from requests import Session, Request
 from requests.structures import CaseInsensitiveDict
@@ -50,7 +50,7 @@ class ContextHttp(object):
                 params=None, json=None, allow_redirects=True, lazy=False):
         if is_mapping(params):
             params = list(params.items())
-        url = normalize_url(url, extra_query_args=params)
+
         method = method.upper().strip()
         request = Request(method, url, data=data, headers=headers,
                           json=json, auth=auth)
@@ -141,7 +141,7 @@ class ContextHttpResponse(object):
                 etag = headers.get('etag')
                 if etag:
                     request.headers['If-None-Match'] = etag
-            
+
             self._rate_limit(request.url)
 
             session = self.http.session
@@ -211,12 +211,12 @@ class ContextHttpResponse(object):
         if self._request_id is not None:
             return self._request_id
         if self.request is not None:
-            parts = [self.request.method, self.url]
+            parts = [self.request.method, normalize_url(self.url)]
             if self.request.data:
                 parts.append(hash_data(self.request.data))
             if self.request.json:
                 parts.append(hash_data(self.request.json))
-            return ' '.join(parts)
+            return make_key(*parts)
 
     @property
     def status_code(self):
