@@ -29,31 +29,33 @@ def parse_html(context, data, result):
     else:
         roots = []
         for path in include:
-            roots = roots + result.html.findall(path)
+            roots = roots + result.html.xpath(path)
 
     seen = set()
     for root in roots:
         for tag_query, attr_name in URL_TAGS:
-            for element in root.findall(tag_query):
+            for element in root.xpath(tag_query):
                 attr = element.get(attr_name)
                 if attr is None:
                     continue
 
                 try:
-                    url = normalize_url(urljoin(result.url, attr))
+                    url = urljoin(result.url, attr)
+                    key = normalize_url(url)
                 except Exception:
                     log.warning('Invalid URL: %r', attr)
                     continue
 
-                if url is None or url in seen:
+                if url is None or key is None or key in seen:
                     continue
-                seen.add(url)
+                seen.add(key)
 
-                tag = make_key(context.run_id, url)
+                tag = make_key(context.run_id, key)
                 if context.check_tag(tag):
                     continue
                 context.set_tag(tag, None)
                 data = {'url': url}
+
                 # Option to set the document title from the link text.
                 if context.get('link_title', False):
                     data['title'] = collapse_spaces(element.text_content())
