@@ -10,6 +10,6 @@ class TestDocumentCloud(object):
         mocker.patch.object(context, "recurse")
 
         documentcloud_query(context, data)
-        assert context.emit.call_count == 100
+        assert context.emit.call_count >= 10
         assert context.recurse.call_count == 1
         context.recurse.assert_called_once_with(data={'page': 2})
