@@ -9,12 +9,17 @@ log = logging.getLogger(__name__)
 
 
 class MemoriousWorker(Worker):
+    def boot(self):
+        self.scheduler = get_rate_limit('scheduler',
+                                        unit=60,
+                                        interval=settings.SCHEDULER_INTERVAL,
+                                        limit=1)
 
     def periodic(self):
-        rate_limit = get_rate_limit('scheduler', unit=60, interval=10, limit=1)
-        if rate_limit.check() and not settings.DEBUG:
+        if self.scheduler.check() and not settings.DEBUG:
+            log.info("Running scheduled crawlers ...")
+            self.scheduler.update()
             manager.run_scheduled()
-            rate_limit.update()
 
     def handle(self, task):
         data = task.payload
@@ -26,10 +31,10 @@ class MemoriousWorker(Worker):
         context.execute(data)
 
     def after_task(self, task):
-        stage = task.stage.stage
-        state = task.context
-        context = Context.from_state(state, stage)
         if task.job.is_done():
+            stage = task.stage.stage
+            state = task.context
+            context = Context.from_state(state, stage)
             context.crawler.aggregate(context)
 
     def get_stages(self):
